==> xlang-0.7.1.tar.gz: xlang-0.7.1/src/xlang/langbasic_yacc.h <==
/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     AS = 267,
     END = 268,
     FUNCTION = 269,
     SUB = 270,
     THEN = 271,
     V_NULL = 272,
     VOID = 273,
     CHAR = 274,
     UCHAR = 275,
     SHORT = 276,
     USHORT = 277,
     INT = 278,
     UINT = 279,
     FLOAT = 280,
     DOUBLE = 281,
     STRING = 282,
     BOOL = 283,
     HANDLE = 284,
     IDENTIFIER = 285,
     V_INT = 286,
     V_FLOAT = 287,
     V_STRING = 288
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define AS 267
#define END 268
#define FUNCTION 269
#define SUB 270
#define THEN 271
#define V_NULL 272
#define VOID 273
#define CHAR 274
#define UCHAR 275
#define SHORT 276
#define USHORT 277
#define INT 278
#define UINT 279
#define FLOAT 280
#define DOUBLE 281
#define STRING 282
#define BOOL 283
#define HANDLE 284
#define IDENTIFIER 285
#define V_INT 286
#define V_FLOAT 287
#define V_STRING 288




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 35 "langbasic_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 1252 of yacc.c.  */
#line 112 "langbasic_yacc.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE basic_lval;

==> xlang-0.7.4.tar.gz: xlang-0.7.4/src/xlang/langbasic_yacc.h <==
/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     AS = 267,
     END = 268,
     FUNCTION = 269,
     SUB = 270,
     THEN = 271,
     V_NULL = 272,
     VOID = 273,
     CHAR = 274,
     UCHAR = 275,
     SHORT = 276,
     USHORT = 277,
     INT = 278,
     UINT = 279,
     FLOAT = 280,
     DOUBLE = 281,
     STRING = 282,
     BOOL = 283,
     HANDLE = 284,
     IDENTIFIER = 285,
     V_INT = 286,
     V_FLOAT = 287,
     V_STRING = 288
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define AS 267
#define END 268
#define FUNCTION 269
#define SUB 270
#define THEN 271
#define V_NULL 272
#define VOID 273
#define CHAR 274
#define UCHAR 275
#define SHORT 276
#define USHORT 277
#define INT 278
#define UINT 279
#define FLOAT 280
#define DOUBLE 281
#define STRING 282
#define BOOL 283
#define HANDLE 284
#define IDENTIFIER 285
#define V_INT 286
#define V_FLOAT 287
#define V_STRING 288




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 35 "parser/basiclike/langbasic_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 1252 of yacc.c.  */
#line 112 "langbasic_yacc.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE basic_lval;
